# encoding: UTF-8
require 'thor'
require 'sinatra'
require_relative 'web'
require_relative 'version'
include Minireq::Site

module Minireq
  module Site

    class Cli < Thor
      include Thor::Actions

      map %w[--version -v] => :__print_version

			no_commands {
				def __under_construction
					puts "UNDER_CONSTRUCTION"
				end

				def __exec_asynchronously(command)
					pid = spawn(command)
					Process.detach(pid)
				end
			}

			desc "--version, -v", "Print the version"
      def __print_version
        puts "minireq-site #{Minireq::Site::VERSION}"
      end

			desc "serve [REPOSITORY]", "Serve web application for REPOSITORY"
			method_option :port, aliases: "-p", type: :numeric, desc: "port"
			def serve(repository = Dir.pwd)
        Dir.chdir(repository) { `minireq doc` }
        Sinatra::Application.port = options[:port] if options[:port]
        Sinatra::Application.public_folder = File.join(repository, "docs")
        Sinatra::Application.run!
      end

    end
  end
end
