# encoding: UTF-8

require 'kramdown'
require_relative 'markdown_translator'

# Markdonw is a wrapper over Kramdown::Document that
# * translate my atom.io ``` code block to kramdown ~~~ code block
# * and provides #toc
#
# Take care of two things about config - it must:
# * have one empty line before any table;
# * have one empty line before any code block;
# * have one empty line befora any list;
# * char "|", even escaped as "\|" can bring some problem;
# * have two space indentation in lists.
#
# Usage:
#
#     md = Markdown.new(File.read("document.md"))
#     File.write("document.html", md.toc << "\n" << md.html)
#
class Kmarkdown < Kramdown::Document
  include MarkdownTranslator

  def initialize(text, options = {})
    to_kramdown!(text)
    options.merge! DEFAULT_OPTIONS
    super(text, options)
  end

  def html
    to_html
  end

  def toc
    build_toc(to_toc)
  end

  protected

    DEFAULT_OPTIONS = {
      syntax_highlighter: nil,
      syntax_highlighter_opts: {}
    }
      # syntax_highlighter: :rouge,
      # syntax_highlighter_opts: { line_numbers: false }

    def build_toc(toc, html = nil)
      html ||= ""
      html << "<ul>\n"
      toc.children.inject(html) do |s, h|
        s << "<li>" << build_link(h)
        build_toc(h, s) unless h.children.empty?
        s << "</li>\n"
      end
      html << "</ul>\n"
    end

    def build_link(toc)
      id = toc.attr[:id]
      text = toc.value.options[:raw_text]
      "<a href=\"##{id}\">#{text}</a>"
    end
end
