require 'sinatra'
require 'sinatra/content_for'
require 'haml'
require_relative 'kmarkdown'

configure do
  enable :inline_templates
  set :environment, :production
  set :haml, { :ugly => true }
  set :public_folder, proc { fail "Must set public folder!" }
end

get '/' do
  markdown = File.join(settings.public_folder, "requirements.md")
  mdoc = Kmarkdown.new(File.read(markdown))
  @doc = mdoc.html
  @toc = mdoc.toc
  haml :index
end

# TODO check format parameter is odt or pdf?
get 'download/:fmt' do
  send_file File.join(settings.public_folder, "requirements.md")
end

__END__

@@ index
- content_for :toc do
  %chunk{ :of => "html" } #{@toc}

- content_for :doc do
  %chunk{ :of => "html" } #{@doc}

@@ layout
!!!
%html
  %head
    %title Minireq::Site
  %body
    .container
      %header
        %h1 Minireq::Site
        %a{title: "Download", href: "/download/pdf"} Download document for offline usage.

      %toc
        %h1 Contents
        = yield_content :toc

      %doc
        %h1 Software Requirements Specification
        = yield_content :doc

      %footer
        %p
          &copy; 2016
          %a{title: "Open Minireq::Site", href:   "https://github.com/nvoynov/minireq-site"} Minireq::Site
